@@ -50,6 +50,19 @@ class TestFormat(object):
         sql = 'select-- foo\nfrom -- bar\nwhere'
         res = sqlparse.format(sql, strip_comments=True)
         assert res == 'select from where'
+        sql = 'select *-- statement starts here\n\nfrom foo'
+        res = sqlparse.format(sql, strip_comments=True)
+        assert res == 'select * from foo'
+        sql = 'select * from foo-- statement starts here\nwhere'
+        res = sqlparse.format(sql, strip_comments=True)
+        assert res == 'select * from foo where'
+        sql = 'select a-- statement starts here\nfrom foo'
+        res = sqlparse.format(sql, strip_comments=True)
+        assert res == 'select a from foo'
+        sql = '--comment\nselect a-- statement starts here\n' \
+              'from foo--comment\nf'
+        res = sqlparse.format(sql, strip_comments=True)
+        assert res == 'select a from foo f'
 
     def test_strip_comments_invalid_option(self):
         sql = 'select-- foo\nfrom -- bar\nwhere'
@@ -106,8 +119,8 @@ class TestFormat(object):
         assert f(s1) == "SELECT some_column LIKE 'value\r'"
         assert f(s2) == "SELECT some_column LIKE 'value\r'\nWHERE id = 1\n"
         assert f(s3) == "SELECT some_column LIKE 'value\\'\r' WHERE id = 1\n"
-        assert (f(s4) ==
-                "SELECT some_column LIKE 'value\\\\\\'\r' WHERE id = 1\n")
+        assert (f(s4)
+                == "SELECT some_column LIKE 'value\\\\\\'\r' WHERE id = 1\n")
 
 
 class TestFormatReindentAligned(object):
@@ -362,6 +375,11 @@ class TestFormatReindent(object):
             'from',
             '  (select *',
             '   from foo);'])
+        assert f("select f(1)") == 'select f(1)'
+        assert f("select f( 1 )") == 'select f(1)'
+        assert f("select f(\n\n\n1\n\n\n)") == 'select f(1)'
+        assert f("select f(\n\n\n 1 \n\n\n)") == 'select f(1)'
+        assert f("select f(\n\n\n  1  \n\n\n)") == 'select f(1)'
 
     def test_where(self):
         f = lambda sql: sqlparse.format(sql, reindent=True)
@@ -453,6 +471,18 @@ class TestFormatReindent(object):
             "       col3",
             "from my_table"])
 
+    def test_long_identifier_list_with_functions(self):
+        f = lambda sql: sqlparse.format(sql, reindent=True, wrap_after=30)
+        s = ("select 'abc' as foo, json_build_object('a',  a,"
+             "'b', b, 'c', c, 'd', d, 'e', e) as col2"
+             "col3 from my_table")
+        assert f(s) == '\n'.join([
+            "select 'abc' as foo,",
+            "       json_build_object('a',",
+            "         a, 'b', b, 'c', c, 'd', d,",
+            "         'e', e) as col2col3",
+            "from my_table"])
+
     def test_case(self):
         f = lambda sql: sqlparse.format(sql, reindent=True)
         s = 'case when foo = 1 then 2 when foo = 3 then 4 else 5 end'
@@ -524,6 +554,49 @@ class TestFormatReindent(object):
             '       nvl(1)',
             'from dual'])
 
+    def test_insert_values(self):
+        # issue 329
+        f = lambda sql: sqlparse.format(sql, reindent=True)
+        s = 'insert into foo values (1, 2)'
+        assert f(s) == '\n'.join([
+            'insert into foo',
+            'values (1, 2)'])
+
+        s = 'insert into foo values (1, 2), (3, 4), (5, 6)'
+        assert f(s) == '\n'.join([
+            'insert into foo',
+            'values (1, 2),',
+            '       (3, 4),',
+            '       (5, 6)'])
+
+        s = 'insert into foo(a, b) values (1, 2), (3, 4), (5, 6)'
+        assert f(s) == '\n'.join([
+            'insert into foo(a, b)',
+            'values (1, 2),',
+            '       (3, 4),',
+            '       (5, 6)'])
+
+        f = lambda sql: sqlparse.format(sql, reindent=True,
+                                        comma_first=True)
+        s = 'insert into foo values (1, 2)'
+        assert f(s) == '\n'.join([
+            'insert into foo',
+            'values (1, 2)'])
+
+        s = 'insert into foo values (1, 2), (3, 4), (5, 6)'
+        assert f(s) == '\n'.join([
+            'insert into foo',
+            'values (1, 2)',
+            '     , (3, 4)',
+            '     , (5, 6)'])
+
+        s = 'insert into foo(a, b) values (1, 2), (3, 4), (5, 6)'
+        assert f(s) == '\n'.join([
+            'insert into foo(a, b)',
+            'values (1, 2)',
+            '     , (3, 4)',
+            '     , (5, 6)'])
+
 
 class TestOutputFormat(object):
     def test_python(self):
