@@ -49,10 +49,13 @@ def test_grouping_identifiers():
     assert str(parsed) == s
     assert isinstance(parsed.tokens[-1].tokens[3], sql.Identifier)
 
-    s = "INSERT INTO `test` VALUES('foo', 'bar');"
-    parsed = sqlparse.parse(s)[0]
-    types = [l.ttype for l in parsed.tokens if not l.is_whitespace]
-    assert types == [T.DML, T.Keyword, None, T.Keyword, None, T.Punctuation]
+    for s in ["INSERT INTO `test` VALUES('foo', 'bar');",
+              "INSERT INTO `test` VALUES(1, 2), (3, 4), (5, 6);",
+              "INSERT INTO `test(a, b)` VALUES(1, 2), (3, 4), (5, 6);"]:
+        parsed = sqlparse.parse(s)[0]
+        types = [l.ttype for l in parsed.tokens if not l.is_whitespace]
+        assert types == [T.DML, T.Keyword, None, None, T.Punctuation]
+        assert isinstance(parsed.tokens[6], sql.Values)
 
     s = "select 1.0*(a+b) as col, sum(c)/sum(d) from myschema.mytable"
     parsed = sqlparse.parse(s)[0]
@@ -208,7 +211,7 @@ def test_grouping_where():
     s = 'select * from foo where bar = 1 order by id desc'
     p = sqlparse.parse(s)[0]
     assert str(p) == s
-    assert len(p.tokens) == 14
+    assert len(p.tokens) == 12
 
     s = 'select x from (select y from foo where bar = 1) z'
     p = sqlparse.parse(s)[0]
@@ -283,7 +286,7 @@ def test_grouping_alias_case():
 
 def test_grouping_subquery_no_parens():
     # Not totally sure if this is the right approach...
-    # When a THEN clause contains a subquery w/o parens around it *and*
+    # When a THEN clause contains a subquery w/o parenthesis around it *and*
     # a WHERE condition, the WHERE grouper consumes END too.
     # This takes makes sure that it doesn't fail.
     p = sqlparse.parse('CASE WHEN 1 THEN select 2 where foo = 1 end')[0]
