@@ -250,8 +250,8 @@ def test_issue193_splitting_function():
                  RETURN x;
                 END;
                 SELECT * FROM a.b;"""
-    splitted = sqlparse.split(sql)
-    assert len(splitted) == 2
+    statements = sqlparse.split(sql)
+    assert len(statements) == 2
 
 
 def test_issue194_splitting_function():
@@ -264,8 +264,8 @@ def test_issue194_splitting_function():
                  RETURN x;
                 END;
                 SELECT * FROM a.b;"""
-    splitted = sqlparse.split(sql)
-    assert len(splitted) == 2
+    statements = sqlparse.split(sql)
+    assert len(statements) == 2
 
 
 def test_issue186_get_type():
@@ -277,8 +277,8 @@ def test_issue186_get_type():
 def test_issue212_py2unicode():
     t1 = sql.Token(T.String, u'schöner ')
     t2 = sql.Token(T.String, 'bug')
-    l = sql.TokenList([t1, t2])
-    assert str(l) == 'schöner bug'
+    token_list = sql.TokenList([t1, t2])
+    assert str(token_list) == 'schöner bug'
 
 
 def test_issue213_leadingws():
@@ -366,3 +366,10 @@ def test_issue322_concurrently_is_keyword():
 def test_issue359_index_error_assignments(s):
     sqlparse.parse(s)
     sqlparse.format(s, strip_comments=True)
+
+
+def test_issue469_copy_as_psql_command():
+    formatted = sqlparse.format(
+        '\\copy select * from foo',
+        keyword_case='upper', identifier_case='capitalize')
+    assert formatted == '\\copy SELECT * FROM Foo'
