@@ -52,6 +52,22 @@ def test_split_dashcomments_eol(s):
     assert len(stmts) == 1
 
 
+def test_split_slashcomments(load_file):
+    sql = load_file('slashcomment.sql')
+    stmts = sqlparse.parse(sql)
+    assert len(stmts) == 3
+    assert ''.join(str(q) for q in stmts) == sql
+
+
+@pytest.mark.parametrize('s', ['select foo; // comment\n',
+                               'select foo; // comment\r',
+                               'select foo; // comment\r\n',
+                               'select foo; // comment'])
+def test_split_slashcomments_eol(s):
+    stmts = sqlparse.parse(s)
+    assert len(stmts) == 1
+
+
 def test_split_begintag(load_file):
     sql = load_file('begintag.sql')
     stmts = sqlparse.parse(sql)
@@ -139,3 +155,13 @@ def test_split_simple():
     assert len(stmts) == 2
     assert stmts[0] == 'select * from foo;'
     assert stmts[1] == 'select * from bar;'
+
+
+def test_split_quotes_with_new_line():
+    stmts = sqlparse.split('select "foo\nbar"')
+    assert len(stmts) == 1
+    assert stmts[0] == 'select "foo\nbar"'
+
+    stmts = sqlparse.split("select 'foo\n\bar'")
+    assert len(stmts) == 1
+    assert stmts[0] == "select 'foo\n\bar'"
